/**********************************************************************
 *
 * Jdb2Txt.java -- 
 * A component of the Greenstone digital library software
 * from the New Zealand Digital Library Project at the 
 * University of Waikato, New Zealand.
 *
 * Copyright (C) 1999  The New Zealand Digital Library Project
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 **********************************************************************/

import jdbm.RecordManager;
import jdbm.RecordManagerFactory;
import jdbm.helper.FastIterator;
import jdbm.htree.HTree;

import java.io.IOException;
import java.util.Properties;


public class Jdb2Txt
{
    static String TNAME = "greenstone";

    RecordManager  recman_;
    HTree          hashtable_;


    public Jdb2Txt(String db_filename)
	throws IOException
    {
        // create or open a record manager
        Properties props = new Properties();
        recman_ = RecordManagerFactory.createRecordManager(db_filename, props);

        // create or load table
        long recid = recman_.getNamedObject(TNAME);
        if (recid != 0) {
            hashtable_ = HTree.load(recman_, recid);
        } 
	else {
            System.err.println("Failed to find database table '" + TNAME +"' ...");
	    System.exit(-1);
        }
    }


    public void db2txt()
        throws IOException
    {
	FastIterator   iter;
	String         key;
	String         val;

        iter = hashtable_.keys();
        key = (String) iter.next();
        while (key != null) {
            val = (String) hashtable_.get(key);
            System.out.println("[" + key + "]");
            System.out.println(val);
	    // 70 hypens
	    System.out.println("----------------------------------------------------------------------");
            key = (String) iter.next();
        }
        
        recman_.close();
    }


    public static void print_usage()
    {
	System.err.println("Usage: java Jdb2Txt database-name");
	System.exit(-1);
    }

   
    public static void main(String[] args)
    {
	if (args.length != 1) {
	    print_usage();
	}

	String dbname = args[0];

        try {

            Jdb2Txt table = new Jdb2Txt(dbname);
            table.db2txt();
        } 
	catch (IOException e) {
            e.printStackTrace();
        }
    }

}