/**********************************************************************
 *
 * JdbSet.java -- 
 * A component of the Greenstone digital library software
 * from the New Zealand Digital Library Project at the 
 * University of Waikato, New Zealand.
 *
 * Copyright (C) 1999  The New Zealand Digital Library Project
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 **********************************************************************/

import java.io.BufferedInputStream;
import java.io.InputStream;

import jdbm.RecordManager;
import jdbm.RecordManagerFactory;
import jdbm.helper.FastIterator;
import jdbm.htree.HTree;

import java.io.IOException;
import java.util.Properties;


public class JdbSet
{
    static String TNAME = "greenstone";

    RecordManager  recman_;
    HTree          hashtable_;

    public JdbSet(String db_filename)
	throws IOException
    {
        // create or open a record manager
        Properties props = new Properties();
        recman_ = RecordManagerFactory.createRecordManager(db_filename, props);

        // load existing table (if exists) otherwise create new one
        long recid = recman_.getNamedObject(TNAME);

	if (recid != 0) {
	    System.out.println("Loading existing database table '" + TNAME +"' ...");
	    hashtable_ = HTree.load(recman_, recid);
	}
	else {
	    System.out.println("No database table '" + TNAME +"' to set.  Creating new one");
	    hashtable_ = HTree.createInstance(recman_);
	    recman_.setNamedObject(TNAME, hashtable_.getRecid());
	}
    }
    
    public void append(String key, String val)
	throws IOException
    {
    	    
	String orig_val = (String)hashtable_.get(key);           
	String new_val = orig_val + val;

	hashtable_.put(key,new_val);
	recman_.close();
    }

    public void set(String key, String val)
	throws IOException
	       
    {
	hashtable_.put(key,val);
	recman_.close();
    }

    public void del(String key)
	throws IOException
    {
	hashtable_.remove(key);
	recman_.close();
    }
    

    public static void print_usage()
    {
	System.err.println("Usage: java JdbSet database-name key [value] [append]");
	System.err.println("\t- if no value is given then the lexicon indicated by the key is removed");
	System.err.println("\t- if a value is given followed by 'append' then the value is ");
	System.err.println("\t  added to the existing entry rather than overwriting it");
	System.exit(-1);
    }

    
    public static void main(String[] args)
    {
	int argc = args.length;

	// sanity check
	if ((argc < 2) || (argc>4)) {
	    print_usage();
	}

	try {
	    String dbname = args[0];
	    JdbSet table = new JdbSet(dbname);
	    
	    if (argc == 4) {
		
		if (args[3].equals("append")) {
		    String key = args[1];
		    String val = args[2];
		    
		    table.append(key,val);
		}
		else {
		    System.err.println("Error: Unrecognised option " + args[3]);
		    print_usage();
		}
	    }
	    else if (argc == 3) {
		String key = args[1];
		String val = args[2];
		table.set(key,val);
	    }
	    else {
		String key = args[1];
		table.del(key);
	    }
	}

	catch (IOException e) {
	    e.printStackTrace();
	}
		
    }

}


